@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Log::Any '$log';
 
-our $VERSION = '0.19'; # VERSION
+our $VERSION = '0.20'; # VERSION
 
 use File::HomeDir;
 use HTTP::Daemon;
@@ -52,6 +52,8 @@ has _app                   => (is => 'rw'); # store PSGI app
 has product_name           => (is => 'rw');
 has product_version        => (is => 'rw');
 
+has "ssl_$_" => (is => 'rw') for (qw(verify_mode verify_callback ca_path ca_file));
+
 sub BUILD {
     my ($self) = @_;
 
@@ -78,6 +80,11 @@ sub BUILD {
         no strict;
         $self->product_version($Gepok::VERSION // "?");
     }
+    if (defined (my $vc = $self->ssl_verify_callback)) {
+        $self->ssl_verify_callback($vc = sub { 0 }) if $vc eq '0';
+        $self->ssl_verify_callback($vc = sub { 1 }) if $vc eq '1';
+        die "ssl_verify_callback needs to be a coderef, or constant '1' or '0'" unless ref $vc eq 'CODE';
+    }
     unless ($self->_daemon) {
         my $daemon = SHARYANTO::Proc::Daemon::Prefork->new(
             name                    => $self->name,
@@ -141,7 +148,7 @@ sub _after_init {
         $args{Local}   = $path;
         $log->infof("Binding to Unix socket %s (http) ...", $path);
         my $sock = HTTP::Daemon::UNIX->new(%args);
-        die "Unable to bind to Unix socket $path" unless $sock;
+        die "Unable to bind to Unix socket $path: $@" unless $sock;
         push @server_socks, $sock;
         push @server_sock_infos, "$path (unix)";
     }
@@ -177,8 +184,13 @@ sub _after_init {
 
         $args{SSL_key_file}  = $self->ssl_key_file;
         $args{SSL_cert_file} = $self->ssl_cert_file;
-        #$args{SSL_ca_file} = $self->ssl_ca_file;
-        #$args{SSL_verify_mode} => 0x01;
+
+        for (qw(verify_mode verify_callback ca_path ca_file)) {
+            my $meth = "ssl_$_";
+            my $val  = $self->$meth;
+            $args{"SSL_$_"} = $val if defined $val;
+        }
+
         if ($port =~ /^(?:0\.0\.0\.0)?:?(\d+)$/) {
             $args{LocalPort} = $1;
         } elsif ($port =~ /^(\d+\.\d+\.\d+\.\d+):(\d+)$/) {
@@ -214,7 +226,7 @@ sub _main_loop {
 
     my $sel = IO::Select->new(@{ $self->_server_socks });
 
-    for (my $i=1; $i<$self->max_requests_per_child; $i++) {
+    for (my $i=1; $i<=$self->max_requests_per_child; $i++) {
         $self->_daemon->set_label("listening");
         my @ready = $sel->can_read();
         for my $s (@ready) {
@@ -555,6 +567,8 @@ sub access_log {
     }
 }
 
+1;
+
 # ABSTRACT: PSGI server with built-in HTTPS support, Unix sockets, preforking
 
 
@@ -566,7 +580,7 @@ Gepok - PSGI server with built-in HTTPS support, Unix sockets, preforking
 
 =head1 VERSION
 
-version 0.19
+version 0.20
 
 =head1 SYNOPSIS
 
@@ -734,6 +748,26 @@ more HTTPS ports, you need to supply this.
 Path to SSL cert file, to be passed to HTTP::Daemon::SSL. If you specify one or
 more HTTPS ports, you need to supply this.
 
+=head2 ssl_verify_mode => INT
+
+Level of verification for SSL client certificates, to be passed to
+HTTP::Daemon::SSL. This is optional.
+
+=head2 ssl_verify_callback => CODEREF
+
+Custom verifier for SSL client certificates, to be passed to HTTP::Daemon::SSL.
+This is optional.
+
+=head2 ssl_ca_file => STR
+
+Path for file containing certificates of reputable authorties for certificate
+verification. This is optional.
+
+=head2 ssl_ca_path => STR
+
+According to L<IO::Socket::SSL> this is only of interest if you are
+"unusually friendly with the OpenSSL documentation". This is optional.
+
 =head2 start_servers => INT (default 3)
 
 Number of children to fork at the start of run. If you set this to 0, the server
